@@ -22,7 +22,7 @@
 #
 # Bacula is a registered trademark of Kern Sibbald.
 
-__version__ = '0.1.4'
+__version__ = '0.1.5'
 
 import os
 import sys
@@ -40,6 +40,7 @@ import time
 from LogFile import *
 from Database import *
 from Catalog import *
+from SQL import *
 
 # pull in some spaghetti to make this stuff work without fuse-py being installed
 try:
@@ -143,7 +144,7 @@ class FileSystem(Fuse) :
         # default option values
         self.logging = 'info'
         self.syslog = False
-        self.driver = 'sqlite3'
+        self.driver = SQL.SQLITE3
         self.database = None
         self.host = 'localhost'
         self.port = 0
@@ -884,7 +885,7 @@ BaculaFS: exposes the Bacula catalog and storage as a Filesystem in USErspace
     server.parser.add_option(mountopt="username", metavar="USERNAME", default=server.username,
                              help="database user name [default: %default]")
     server.parser.add_option(mountopt="password", metavar="PASSWORD", default=server.password,
-                             help="database password (use '-o password= ' to get a password prompt)")
+                             help="database password (use '-o password= ' to get a password prompt; if not provided, the password is read from the DATABASE_PASSWORD environment variable)")
     server.parser.add_option(mountopt="conf", metavar="PATH", default=server.conf,
                              help="storage daemon configuration file [default: %default]")
     server.parser.add_option(mountopt="client", metavar="CLIENT", default=server.client,
@@ -935,7 +936,6 @@ BaculaFS: exposes the Bacula catalog and storage as a Filesystem in USErspace
             try :
                 server.initialize()
             except :
-                traceback.print_exc()
                 server.shutdown()
                 raise
 
